@@ -133,7 +133,7 @@ our $schema = ['hash', {
 }, {}];
 
 1;
-# ABSTRACT: CPAN Meta specification 2.0
+# ABSTRACT:
 
 __END__
 
@@ -143,11 +143,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::cpan::meta20 - CPAN Meta specification 2.0
+Sah::Schema::cpan::meta20
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::cpan::meta20 (from Perl distribution Sah-Schemas-CPANMeta), released on 2016-07-22.
+This document describes version 0.003 of Sah::Schema::cpan::meta20 (from Perl distribution Sah-Schemas-CPANMeta), released on 2017-01-08.
 
 =head1 HOMEPAGE
 
@@ -155,7 +155,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Schema-Schema-CPANMeta>.
+Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-CPANMeta>.
 
 =head1 BUGS
 
@@ -165,13 +165,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<CPAN::Meta>, L<CPAN::Meta::Validator>
+
+L<validate-cpan-meta-with-sah> from L<App::ValidateCPANMetaWithSah>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
