@@ -1,7 +1,7 @@
 package Sah::Schema::cpan::meta20::optional_feature;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-08'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 our $schema = ['hash', {
     summary => 'Additional information about an optional feature',
@@ -36,7 +36,7 @@ our $schema = ['hash', {
     },
 }, {}];
 
-# ABSTRACT: Additional information about an optional feature
+# ABSTRACT:
 
 __END__
 
@@ -46,11 +46,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::cpan::meta20::optional_feature - Additional information about an optional feature
+Sah::Schema::cpan::meta20::optional_feature
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::cpan::meta20::optional_feature (from Perl distribution Sah-Schemas-CPANMeta), released on 2016-07-22.
+This document describes version 0.003 of Sah::Schema::cpan::meta20::optional_feature (from Perl distribution Sah-Schemas-CPANMeta), released on 2017-01-08.
 
 =head1 HOMEPAGE
 
@@ -58,7 +58,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Schema-Schema-CPANMeta>.
+Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-CPANMeta>.
 
 =head1 BUGS
 
@@ -74,7 +74,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
