@@ -1,7 +1,7 @@
 package Sah::Schema::cpan::meta20::optional_feature_prereqs;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-08'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 our $schema = ['cpan::meta20::prereqs', {
     summary => 'Prereqs hash for optional feature',
@@ -10,10 +10,10 @@ our $schema = ['cpan::meta20::prereqs', {
 Just like a normal prereqs, except it must not include `configure` phase.
 
 _
-    'merge.subtract.allowed_keys' => [qw/configure/],
+    allowed_keys_re => '\A(develop|build|test|runtime|x_\w+)\z',
 }, {}];
 
-# ABSTRACT: Prereqs hash for optional feature
+# ABSTRACT:
 
 __END__
 
@@ -23,11 +23,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::cpan::meta20::optional_feature_prereqs - Prereqs hash for optional feature
+Sah::Schema::cpan::meta20::optional_feature_prereqs
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::cpan::meta20::optional_feature_prereqs (from Perl distribution Sah-Schemas-CPANMeta), released on 2016-07-22.
+This document describes version 0.003 of Sah::Schema::cpan::meta20::optional_feature_prereqs (from Perl distribution Sah-Schemas-CPANMeta), released on 2017-01-08.
 
 =head1 DESCRIPTION
 
@@ -39,7 +39,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Schema-Schema-CPANMeta>.
+Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-CPANMeta>.
 
 =head1 BUGS
 
@@ -55,7 +55,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
