@@ -15,7 +15,7 @@ Sah::Schemas::CPANMeta - Sah schemas for CPAN Meta specification
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schemas::CPANMeta (from Perl distribution Sah-Schemas-CPANMeta), released on 2016-07-22.
+This document describes version 0.003 of Sah::Schemas::CPANMeta (from Perl distribution Sah-Schemas-CPANMeta), released on 2017-01-08.
 
 =head1 SYNOPSIS
 
@@ -25,7 +25,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Schema-Schema-CPANMeta>.
+Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-CPANMeta>.
 
 =head1 BUGS
 
@@ -37,6 +37,10 @@ feature.
 
 =head1 SEE ALSO
 
+L<Sah::Schemas::CPAN>
+
+L<CPAN::Meta>, L<CPAN::Meta::Validator>
+
 L<Sah> - specification
 
 L<Data::Sah>
@@ -47,7 +51,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
